@@ -12,13 +12,13 @@ elastic_panel
 import pkg_resources
 
 try:
-    __version__ = pkg_resources.get_distribution('django-elasticsearch-debug-toolbar').version
+    __version__ = pkg_resources.get_distribution("django-elasticsearch-debug-toolbar").version
 except Exception:
-    __version__ = 'unknown'
+    __version__ = "unknown"
 
 
-__title__ = 'elastic_panel'
-__author__ = 'Benoit Chabord'
-__copyright__ = 'Copyright 2014 Benoit Chabord'
+__title__ = "elastic_panel"
+__author__ = "Benoit Chabord"
+__copyright__ = "Copyright 2014 Benoit Chabord"
 
 VERSION = __version__
