@@ -1,13 +1,14 @@
-from django.conf import settings
-from django.template.loader import render_to_string
-from django.utils.translation import ugettext_lazy as _
-from debug_toolbar.panels import Panel
-from debug_toolbar.utils import ThreadCollector
 import hashlib
 import json
+import traceback
 
+from debug_toolbar.panels import Panel
+from debug_toolbar.utils import ThreadCollector
+from django.templatetags.static import static
+from django.utils.translation import gettext_lazy as _
 from elasticsearch.connection.base import Connection
-#Patching og the orginal elasticsearch log_request
+
+# Patching og the orginal elasticsearch log_request
 old_log_request_success = Connection.log_request_success
 collector = ThreadCollector()
 
@@ -16,13 +17,14 @@ def patched_log_request_success(self, method, full_url, path, body, status_code,
     collector.collect(ElasticQueryInfo(method, full_url, path, body, status_code, response, duration))
     old_log_request_success(self, method, full_url, path, body, status_code, response, duration)
 
+
 Connection.log_request_success = patched_log_request_success
 
 
 def _pretty_json(data):
     # pretty JSON in tracer curl logs
     try:
-        return json.dumps(json.loads(data), sort_keys=True, indent=2, separators=(',', ': ')).replace("'", r'\u0027')
+        return json.dumps(json.loads(data), sort_keys=True, indent=2, separators=(",", ": ")).replace("'", r"\u0027")
     except (ValueError, TypeError):
         # non-json data or a bulk request
         return data
@@ -31,44 +33,61 @@ def _pretty_json(data):
 class ElasticQueryInfo:
     def __init__(self, method, full_url, path, body, status_code, response, duration):
         if not body:
-            body = b''  # Python 3 TypeError if None
+            self.body = ""  # Python 3 TypeError if None
+        else:
+            self.body = _pretty_json(body)
+            if isinstance(self.body, bytes):
+                self.body = self.body.decode("ascii", "ignore")
+        self.traceback = "".join(traceback.format_stack()[:-2])
         self.method = method
         self.full_url = full_url
         self.path = path
-        self.body = _pretty_json(body)
         self.status_code = status_code
         self.response = _pretty_json(response)
         self.duration = round(duration * 1000, 2)
-        self.hash = hashlib.md5(self.full_url.encode('ascii', 'ignore') + self.body).hexdigest()
+        self.hash = hashlib.md5(
+            self.full_url.encode("ascii", "ignore") + self.body.encode("ascii", "ignore")
+        ).hexdigest()
 
 
 class ElasticDebugPanel(Panel):
     """
     Panel that displays queries made by Elasticsearch backends.
     """
-    name = 'Elasticsearch'
-    template = 'elastic_panel/elastic_panel.html'
+
+    name = "Elasticsearch"
+    template = "elastic_panel/elastic_panel.html"
     has_content = True
+    total_time = 0
+    nb_duplicates = 0
+    nb_queries = 0
 
+    @property
     def nav_title(self):
-        return _('Elastic Queries')
+        return _("Elastic Queries")
 
+    @property
     def nav_subtitle(self):
-        default_str = "{} queries {}ms".format(self.nb_queries, self.total_time)
+        default_str = "{} queries {:.2f}ms".format(self.nb_queries, self.total_time)
         if self.nb_duplicates > 0:
             default_str += " {} DUPE".format(self.nb_duplicates)
         return default_str
 
-    def url(self):
-        return ''
-
+    @property
     def title(self):
-        return self.nav_title()
+        return self.nav_title
+
+    @property
+    def scripts(self):
+        scripts = super().scripts
+        scripts.append(static("elastic_panel/js/elastic_panel.js"))
+        return scripts
 
     def process_request(self, request):
         collector.clear_collection()
+        return super().process_request(request)
 
-    def process_response(self, request, response):
+    def generate_stats(self, request, response):
         records = collector.get_collection()
         self.total_time = 0
         self.nb_duplicates = 0
@@ -83,4 +102,4 @@ class ElasticDebugPanel(Panel):
         self.nb_queries = len(records)
 
         collector.clear_collection()
-        self.record_stats({'records': records})
+        self.record_stats({"records": records})
